function [cellformat]=cellrow2form(cellrow, is4tab, doquote, dotab)
% function [cellformat]=cellrow2form(cellrow, is4tab, doquote, dotab)
% determines format information of a row of a cell array
% the contents can either be numeric or string.
% IN
% cellrow:      one dimensional cell array with entries either being
%               numerical or string
% is4tab:       optional boolean if available and true generates data 
%               fromat for latex table
% doquote:       optional boolean, if 1 then we quote strings.
% dotab:         optional boolean, if 1 then separators are tabulators,
%                otherwise we use comma. 
% OUT
% cellformat:   for is4tab true this is a cell array of strigs each
%               specifying the fromat of a cell column.
%               for is4tab false this is a format string corresponding 
%               to the ceontents of the array.
%
% (C) P. Sykacek 2005

if nargin < 2
    is4tab=0;
end
if nargin<3
    doquote=0;
end
if nargin<4
    dotab=0;
end
ncnt=length(cellrow);
if is4tab
    cellformat={};
    for n=1:ncnt
        if ischar(cellrow{n})
            cellformat{n}='%s';
        elseif isnumeric(cellrow{n})
            cellformat{n}='%8.5g';
        end
    end
    cellformat=cellformat(:);
else
    cellformat=[];
    if dotab
      sep=sprintf('\t');
    else
      sep=',';
    end
    for n=1:ncnt
        if ischar(cellrow{n})
            if doquote
                cellformat=[cellformat, '"%s"',sep];
            else
                cellformat=[cellformat, '%s',sep];
            end
        elseif isnumeric(cellrow{n})
            cellformat=[cellformat, '%16.16g',sep];
        end
    end
    cellformat=cellformat(1:length(cellformat)-1);
    cellformat=[cellformat, sprintf('\n')];
end