function [InTr, TrgTr, InTs, TrgTs] = nfldvdat(X,nfold,step,oneofc)
%function [InTr, TrgTr, InTs, TrgTs] = nfldvdat(X,nfold,step,oneofc)
%Calculates training and test data for n-fold cross validation from the data matrix X.
%X is expected to contain the target data in the first column. The classes are labeled
%with integer numbers starting at 0.
%The target matrices contain the target as 1 of c coding scheme. 
%For c classes the target matrix has c rows with all entries but one set to 0.
%nfold contains mumber of splits in the data; step contains the current step
%e.g. nfold = 10 step = 1..10 are valid.
%InTr and TrgTr contain 100/(nfold-1) % of data the rest is test data.
% changed !!!! :
%oneofc controls whether a seperate one of c target coding scheme matrix
%(TrgTr and TrgTs) is generated. For R. Neals Bayesian inference we need 
%the target data as last column in the InTr and InTs matrices.
% Changed Sep 2003:
% oneofc can be 1 0 or -1. 1 and 0 see above. In addition the value -1
% indicates that the target values are not reshuffeled like it is done in
% case of 0.

InTr=[]; TrgTr=[]; InTs=[]; TrgTs=[];

NrClss=max(X(:,1))+1;	% Nr of classes only necessary for one of c target coding.

XRows=size(X,1);

TsStart = round(XRows * (step-1) / nfold)+1;
TsEnd = round(XRows * step / nfold);

NrTst=TsEnd-TsStart+1;

NrTr=XRows-NrTst;

%no problem if second value after colon is less than first -- empty vector !!
TrRows=[1:TsStart-1, TsEnd+1:XRows];		% vector of row indices for training data
TsRows=[TsStart : TsEnd];			% vector of row indices for test data
if oneofc==1
  % one of c target coding as used for nn toolbox
  InTr=X(TrRows,1:size(X,2))';			% training data -- input
  InTs=X(TsRows,2:size(X,2))';			% test data -- input
  
  TrgTr=zeros(NrClss,NrTr);			% fill target matrices with zeros
  TrgTs=zeros(NrClss,NrTst);
  
  for i=1:NrTr
    TrgTr(X(TrRows(i),1)+1,i)=1;
  end
  
  for i=1:NrTst
    TrgTs(X(TsRows(i),1)+1,i)=1;
  end
elseif oneofc == 0
  % coding used for R.Neals Bayesian inference
  X=[X(:,2:size(X,2)), X(:,1)]; %first put target values into lasty column
  InTr=X(TrRows,:);			% training data -- input and targets
  InTs=X(TsRows,:);			% test data -- input and targets
else
  % coding used for R.Neals Bayesian inference but reshuffling 
  % of targets not necessary
  InTr=X(TrRows,:);			% training data -- input and targets
  InTs=X(TsRows,:);			% test data -- input and targets
end


